<?php

Class WC_Tracking {
	protected static $instance;
	public $link = 'http://parcelsapp.com/en/tracking/';

	public function __construct() {
		if ( ! class_exists('Woocommerce') ) return;

		add_action ( 'add_meta_boxes', array( $this, 'add_meta_box' ), 10, 2 );
		add_action ( 'woocommerce_process_shop_order_meta', array( $this, 'save_meta_box' ), 10 );
	}

	public static function get_instance()  {
        if ( !isset( self::$instance) ) {
            self::$instance = new self();
        }
        return self::$instance;
    }

	public function add_meta_box() {
		add_meta_box ( 'tee-tracking-number', __ ( 'Order tracking', 'basr-core' ), array(
				$this,
				'show_order_tracking_metabox',
			), 'shop_order', 'side', 'high' );
	}

	function show_order_tracking_metabox( $post ) {
		$data                = get_post_custom ( $post->ID );
		$tee_tracking_number = isset( $data['tee_tracking_number'][0] ) ? $data['tee_tracking_number'][0] : '';
		$order_tracking_link = isset( $data['order_tracking_link'][0] ) ? $data['order_tracking_link'][0] : '';

		$fulfill = get_post_meta( $post->ID, 'teeAllover_fulfill', true );
		$fulfill = json_decode( $fulfill );
		$fulfill = tee_convert_obj_to_array( $fulfill, $fulfill );

		// l( $fulfill );
		echo '<div class="tee-tracking">';

		foreach( $fulfill as $key => $tracking ) {
			$this->print_tracking_html( $tracking );
		}
		echo '</div>'; //.tee-tracking 

		echo '<div class="add-more"><span class="button">Add Tracking</span></div>';
		echo '<div class="mail-option"><input type="checkbox" name="tee-resend-tracking">Send Mail for Customer.</div>';
		echo '<input id="teeAllover_fulfill" name="teeAllover_fulfill" type="hidden" value=' . json_encode( $fulfill )  . '>';
		echo '<input id="tee_total_fulfill" name="tee_total_fulfill" type="hidden" value=' . get_post_meta( $post->ID, 'tee_total_fulfill', true )  . '>';
		echo '<input id="tee_total_items" name="tee_total_items" type="hidden" value=' . get_post_meta( $post->ID, 'tee_total_items', true )   . '>';
	}

	function print_tracking_html( $data ) {
		$data = tee_convert_obj_to_array( $data );
		?>
		<div class="track-information">
			<p><span class="notice-dismiss del-tracking"></span></p>
			<p>
				<label
					for="tee_tracking_number"> <?php _e ( 'Tracking code:', 'basr-core' ); ?></label>
				<br />
				<input style="width: 100%" type="text" name="tee_tracking_number" class="tee_tracking_number"
				       placeholder="<?php _e ( 'Enter tracking code', 'basr-core' ); ?>"
				       value="<?php echo $data['tracking_number']; ?>" />
			</p>
			
			<p>
				<label
					for="order_tracking_link"> <?php _e ( 'Tracking link:', 'basr-core' ); ?></label>
				<br />
				<input style="width: 100%" type="text" class="order_tracking_link" name="order_tracking_link"
				       placeholder="<?php _e ( 'Enter Tracking link', 'basr-core' ); ?>"
				       value="<?php echo $data['tracking_url']; ?>" />
			</p>
			<div class="line-items">
				<?php 
				$i = 1;
				foreach ($data['line_items'] as $key => $item) {
					echo '<p class="item">' . $i++ . '. '  . '<span class="item-sku">' . $item['sku'] . '</span>' . ' x <span class="item-quantity">' . $item['quantity'] . '</span></p>';
				}
				?>
			</div>
		</div>
		<?php
	}

	function save_meta_box( $post_id ) {
		$order = wc_get_order ( $post_id );

		if ( $order ) {
			if ( isset( $_POST['teeAllover_fulfill'] ) ) {
				// l( $_POST['teeAllover_fulfill'] );
				update_post_meta( $post_id, 'teeAllover_fulfill', $_POST['teeAllover_fulfill'] );
			}
			if ( isset( $_POST['tee_total_fulfill'] ) ) {
				update_post_meta( $post_id, 'tee_total_fulfill', $_POST['tee_total_fulfill'] );
			}
			if ( isset( $_POST['tee_total_items'] ) ) {
				update_post_meta( $post_id, 'tee_total_items', $_POST['tee_total_items'] );
			}
			if( isset( $_POST['tee_total_fulfill'] ) && isset( $_POST['tee_total_items'] ) ) {
				$is_fulfill = 'Unfulfilled';
				if( $_POST['tee_total_fulfill'] && $_POST['tee_total_fulfill'] <  $_POST['tee_total_items'] ) {
					$is_fulfill = 'Partially-Fulfilled';
				}
				if( $_POST['tee_total_fulfill'] >=  $_POST['tee_total_items'] ) {
					$is_fulfill = 'Fulfilled';
				}
				update_post_meta( $post_id, 'tee_fulfill_status', $is_fulfill );
			}

			$authen = get_post_meta( $post_id, 'teeAllover_order_authen', true );

	 		if ( ! $authen ) {
	 			$authen = 'order-' . $post_id . '-' . md5(uniqid(rand(), true));
	 			update_post_meta( $post_id, 'teeAllover_order_authen', $authen );
	 		}

			if( isset( $_POST['tee-resend-tracking'] ) && $_POST['tee-resend-tracking'] == 'on' ) {
				// sent mail for customer

				if( ! $_POST['teeAllover_fulfill'] ) return;
				$trackings = get_post_meta( $post_id, 'teeAllover_fulfill', true );
				$trackings = json_decode( $trackings );
				$trackings = tee_convert_obj_to_array( $trackings ); 

				$M 	 	  	  = Tee_mail::get_instance();
				$template 	  = $M->get_template( 'Update Tracking Number' );

				$order        = new WC_Order( $post_id );
				$billing_mail = $order->get_billing_email();
				$order_number = $order->get_order_number();

				$obj = new StdClass();
				$obj->site_title   = get_bloginfo( 'name' );
				$obj->site_url     = home_url('/');

				$custom_logo_id    = get_theme_mod( 'custom_logo' );
				if( ! $custom_logo_id ) {
					$logo_img = 'https://pro.teeallover.com/wp-content/uploads/2019/07/tee-allover-600.png';
				} else {
					$logo_img = wp_get_attachment_url( $custom_logo_id );
				}
				$obj->logo         = '<a href="' . $obj->site_url . '"><img src="' . $logo_img . '" alt="logo"></a>';
				$obj->order_number = $order_number;
				$obj->trackings    = '';
				$obj->admin_email  = get_option('admin_email');

				foreach( $trackings as $key => $tracking ) {
					$obj->trackings .= '<a href="' . $tracking['tracking_url'] . '">' . $tracking['tracking_number'] . '</a> ,';
				}
				$obj->trackings = preg_replace('/\s,$/', '.', $obj->trackings);

				$obj->order_url = get_permalink( $post_id );

				l( $obj );

				$rs = $M->sent_mail( 'Update Tracking Number', $billing_mail, $obj );
			}
		}

		return;
		
		if ( $order ) {

			if ( isset( $_POST['tee_tracking_number'] ) ) {
				update_post_meta( $post_id, 'tee_tracking_number', $_POST['tee_tracking_number'] );
			}
			
			if ( isset( $_POST['order_tracking_link'] ) ) {
				update_post_meta( $post_id, 'order_tracking_link', $_POST['order_tracking_link'] );
			}

			$page = get_page_by_title('View Order');
			$view_order_link = '';
	 		if ( is_object( $page ) && isset( $page->ID ) ) {
	 			$view_order_link = get_permalink( $page->ID );
	 		}
	 		$authen = get_post_meta( $post_id, 'tee_shop_order_authen', true );

	 		if ( ! $authen ) {
	 			$authen = uniqid('order-');
	 			update_post_meta( $post_id, 'tee_shop_order_authen', $authen );
	 		}

	 		if ( $view_order_link ) {
	 			$view_order_link = add_query_arg( 'order', $post_id, $view_order_link );
	 			$view_order_link = add_query_arg( 'authen', $authen, $view_order_link );
	 		}

			if ( $_POST['tee_tracking_number'] ) {
				
				$order        = new WC_Order( $post_id );
				$billing_mail = $order->get_billing_email();
				$order_number = $order->get_order_number();
				$M 	 	  	  = Tee_mail::get_instance();
				$template 	  = $M->get_template('sent_tracking');
				if ( ! $template ) return;
				$subject  = $template->post_title . ' #' . $order_number;
				if ( $_POST['order_tracking_link'] ) {
					$link =  $_POST['order_tracking_link'];
				} else {
					$link 	  = $this->link . $_POST['tee_tracking_number'];
				}
				$link = '<a href="' . $link . '">' . $_POST['tee_tracking_number'] . '</a>';

				$store_image = '<img src="' . get_site_icon_url() . '" width="100" alt="logo">';

				$order_url = $view_order_link ? $view_order_link : $order->get_view_order_url();

				$msg 		  = $template->post_content;
				$msg 		  = preg_replace('/{{order\.name}}/', $order_number, $msg);
				$msg 		  = preg_replace('/{{shop\.url}}/', home_url('/'), $msg);
				$msg          = preg_replace('/{{order\.tracking_number}}/', $link, $msg );
				$msg          = preg_replace('/{{order.url}}/', $order_url, $msg );
				$msg          = preg_replace('/{{shop\.img}}/', $store_image, $msg );

				$msg = $M->get_html_format( $msg, 'Shipping Updated!' );

				$email = array( $billing_mail );
				// $email = array( 'haint@byjoomla.com' );

				$rs = wp_mail( $email, $subject, $msg );

			}
		}
	}
}

WC_Tracking::get_instance();
function wpse27856_set_content_type(){
    return "text/html";
}
add_filter( 'wp_mail_content_type','wpse27856_set_content_type' );

add_action( 'woocommerce_update_order', 'tee_fulfillment_woocommerce_order_update', 10, 1 );

function tee_fulfillment_woocommerce_order_update( $order_id ) {

	// 
	if( isset( $_POST['action'] ) && $_POST['action'] == 'editpost' ) {
		return;
	}
	// new
	$new_trackings = get_post_meta( $order_id, 'teeAllover_fulfill_2', true);
	if( ! $new_trackings ) return;
	$new_trackings = json_decode( $new_trackings );

	// crr
	$crr_trackings = get_post_meta( $order_id, 'teeAllover_fulfill', true);

	if( ! $crr_trackings ) {
		$crr_trackings = array();
	} else {
		$crr_trackings = json_decode( $crr_trackings );
	}

	$new_trackings = tee_convert_obj_to_array( $new_trackings );
	$crr_trackings = tee_convert_obj_to_array( $crr_trackings );

	//get old 
	$old_trackings = get_post_meta( $order_id, 'teeAllover_fulfill_1', true);

	if ( $old_trackings ) {
		$old_trackings = json_decode( $old_trackings );
		$old_trackings = tee_convert_obj_to_array( $old_trackings );

		foreach( $old_trackings as $key => $tracking ) {
			foreach( $crr_trackings as $k => $t ) {
				if ( $old_trackings[$key]['tracking_number'] == $crr_trackings[$k]['tracking_number'] ) {
					unset( $crr_trackings[$k] );
				}
			}
		}
	}
	
	$old_trackings = $new_trackings;
	update_post_meta( $order_id, 'teeAllover_fulfill_1', json_encode( $old_trackings ) );

	foreach( $new_trackings as $key => $tracking ) {
		$crr_trackings[] = $tracking;
	}

	update_post_meta( $order_id, 'teeAllover_fulfill', json_encode( $crr_trackings ) );

	// SENT MAIL

	$trackings = get_post_meta( $order_id, 'teeAllover_fulfill', true );
	$trackings = json_decode( $trackings );
	$trackings = tee_convert_obj_to_array( $trackings ); 

	$M 	 	  	  = Tee_mail::get_instance();

	$order        = new WC_Order( $order_id );
	$billing_mail = $order->get_billing_email();
	$order_number = $order->get_order_number();

	$obj = new StdClass();
	$obj->site_title   = get_bloginfo( 'name' );
	$obj->site_url     = home_url('/');
	$custom_logo_id    = get_theme_mod( 'custom_logo' );
	if( ! $custom_logo_id ) {
		$logo_img = 'https://pro.teeallover.com/wp-content/uploads/2019/07/tee-allover-600.png';
	} else {
		$logo_img = wp_get_attachment_url( $custom_logo_id );
	}
	$obj->logo         = '<a href="' . $obj->site_url . '"><img src="' . $logo_img . '" alt="logo"></a>';
	$obj->order_number = $order_number;
	$obj->trackings    = '';
	$obj->admin_email  = get_option('admin_email');

	foreach( $trackings as $key => $tracking ) {
		$obj->trackings .= '<a href="' . $tracking['tracking_url'] . '">' . $tracking['tracking_number'] . '</a> ,';
	}
	$obj->trackings = preg_replace('/\s,$/', '.', $obj->trackings);

	$obj->order_url = get_permalink( $order_id );

	$M->sent_mail( 'Update Tracking Number', $billing_mail, $obj );

}




